# Generated by roxygen2: do not edit by hand

export(gr_baseflow)
export(gr_buffer_geo)
export(gr_check_data)
export(gr_check_params)
export(gr_fill_gaps)
export(gr_from_pardf)
export(gr_get_gaps)
export(gr_get_params)
export(gr_help_params)
export(gr_help_vars)
export(gr_join_rean)
export(gr_kable_tests)
export(gr_plot_acf)
export(gr_plot_hori)
export(gr_plot_matrix)
export(gr_plot_minmonth)
export(gr_plot_periods)
export(gr_plot_ridge)
export(gr_plot_sep)
export(gr_plot_tests)
export(gr_plot_vars)
export(gr_read_rean)
export(gr_report)
export(gr_separate)
export(gr_set_locale)
export(gr_set_param)
export(gr_summarize)
export(gr_test_vars)
export(gr_to_pardf)
importFrom(Rcpp,sourceCpp)
importFrom(graphics,text)
importFrom(rlang,.data)
importFrom(stats,acf)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,density)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,t.test)
importFrom(stats,var.test)
useDynLib(grwat)
