library(grwat)

data(spas) # example Spas-Zagorye data is included with grwat package

# separate
sep = gr_separate(spas, params = gr_get_params(reg = 'center'))

# Default is  English
gr_set_locale('EN')
gr_plot_sep(sep, 1978) 
